#
# spec file for package python-nilearn
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-nilearn
Version:        0.10.1
Release:        2.1
Summary:        Statistical learning tool for neuroimaging
License:        BSD-3-Clause
Group:          Development/Languages/Python
URL:            https://github.com/nilearn/nilearn
Source:         https://files.pythonhosted.org/packages/source/n/nilearn/nilearn-%{version}.tar.gz
# PATCH-FIX-UPSTREAM numpy-1.25.patch gh#nilearn/nilearn#3746
Patch0:         numpy-1.25.patch
# PATCH-FIX-UPSTREAM warning-based-sklearn-version.patch gh#nilearn/nilearn#3763
Patch1:         warning-based-sklearn-version.patch
BuildRequires:  %{python_module base >= 3.7}
BuildRequires:  %{python_module hatch_vcs}
BuildRequires:  %{python_module hatchling}
BuildRequires:  %{python_module pip}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-joblib >= 1.0.0
Requires:       python-matplotlib >= 3.3.0
Requires:       python-nibabel >= 3.2.0
Requires:       python-numpy >= 1.19
Requires:       python-packaging
Requires:       python-pandas >= 1.1.5
Requires:       python-requests >= 2
Requires:       python-scikit-learn >= 1.0.0
Requires:       python-scipy >= 1.6.0
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module joblib >= 1.0.0}
BuildRequires:  %{python_module matplotlib >= 3.3.0}
BuildRequires:  %{python_module nibabel >= 3.2.0}
BuildRequires:  %{python_module numpy >= 1.19}
BuildRequires:  %{python_module packaging}
BuildRequires:  %{python_module pandas >= 1.1.5}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module requests >= 2}
BuildRequires:  %{python_module scikit-learn >= 1.0.0}
BuildRequires:  %{python_module scipy >= 1.6.0}
# /SECTION
%python_subpackages

%description
Nilearn is a Python module for statistical learning on
NeuroImaging data.

%prep
%autosetup -p1 -n nilearn-%{version}
chmod -x nilearn/datasets/tests/data/localizer_index.json
sed -i '1{/env python/d}' nilearn/glm/tests/test_utils.py nilearn/plotting/glass_brain_files/plot_align_svg.py

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# Test try to build the doc and run examples...
rm -rf doc/ examples/
# sporadic race condition in pytest-xdist
donttest="test_with_globbing_patterns_with_single_subject"
# sporadic unknown failure (on all architectures): https://github.com/nilearn/nilearn/issues/2607
donttest+=" or test_check_niimg_wildcard"
# https://github.com/nilearn/nilearn/issues/2608
donttest+=" or test_clean_confounds"
# https://github.com/nilearn/nilearn/issues/2610
donttest+=" or test_reorder_img_mirror"
# ppc64 https://github.com/nilearn/nilearn/issues/3363
donttest+=" or (test_load_confounds and test_nilearn_standardize)"
# x86_64 https://github.com/nilearn/nilearn/issues/3382
donttest+=" or test_tfce_smoke"
donttest+=" or test_load_uniform_ball_cloud"

if [[ $(getconf LONG_BIT) -eq 64 ]]; then
    # this is a noarch rpm package but the pure python code is only intended for 64-bit architectures
%pytest -k "not ($donttest)"
fi

%files %{python_files}
%doc AUTHORS.rst README.rst
%license LICENSE
%{python_sitelib}/nilearn
%{python_sitelib}/nilearn-%{version}*-info

%changelog
* Thu Aug 10 2023 Daniel Garcia <daniel.garcia@suse.com>
- Add numpy-1.25.patch, upstream patch gh#nilearn/nilearn#3746
- Add warning-based-sklearn-version.patch, upstream patch gh#nilearn/nilearn#3763
* Tue Jun 27 2023 Markéta Machová <mmachova@suse.com>
- Update to 0.10.1
  * New function load_sample_motor_activation_image to load example
    contrast map
  * fsaverage meshes accessed through fetch_surf_fsaverage now come
    with flat maps for all resolutions
  * Improve how first_level_from_bids handles fetching slice timing
    metadata and add additional input validation. In release 0.12
    the default slice_time_ref will be None instead of 0
  * Fixes several bugs in first_level_from_bids.
  * Add correct “zscore_sample” strategy to signal._standardize
    which will replace the default “zscore” strategy in release 0.13
  * Moved packaging from setup.py and setuptools build backend to
    pyproject.toml and hatchling backend.
  * Restore resample_img compatibility with all nibabel.spatialimages.SpatialImage objects
* Fri Apr 14 2023 Steve Kowalik <steven.kowalik@suse.com>
- Skip a failing array test.
* Mon Feb  6 2023 Daniel Garcia <daniel.garcia@suse.com>
- Update to 0.10.0
  * New classes MultiNiftiLabelsMasker and MultiNiftiMapsMasker create maskers
    to extract signals from a list of subjects with 4D images using
    parallelization (#3237 by Yasmin Mzayek).
  * Updated docs with a new theme using furo (#3125 by Alexis Thual).
  * permuted_ols and non_parametric_inference now support TFCE statistic (#3196
    by Taylor Salo).
  * permuted_ols and non_parametric_inference now support cluster-level
    Family-wise error correction (#3181 by Taylor Salo).
  * save_glm_to_bids has been added, which writes model outputs to disk
    according to BIDS convention (#2715 by Taylor Salo).
* Tue Oct 11 2022 John Vandenberg <jayvdb@gmail.com>
- Remove fix-test-decoder.patch merged upstream
- Remove use of pytest-xdist which makes failures harder to see
- Update to v0.9.2
  * save_glm_to_bids has been added, which writes model outputs to
    disk according to BIDS convention
  * permuted_ols and non_parametric_inference now support TFCE statistic
  * permuted_ols and non_parametric_inference now support cluster-level
    Family-wise error correction
  * Updated docs with a new theme using furo
  * Fix _NEUROVAULT_BASE_URL and _NEUROSYNTH_FETCH_WORDS_URL in
    nilearn/datasets/neurovault.py by using https instead of http
  * Convert references in nilearn/mass_univariate/permuted_least_squares.py
    to use bibtex format
  * Update Craddock 2012 parcellation url in nilearn/datasets/atlas.py
  * plot_roi failed before when used with the “contours” view type
    and passing a list of cut coordinates in display mode “x”, “y” or “z”;
    this has been corrected
  * plot_markers can now plot a single scatter point
  * Fix title display for plot_surf_stat_map. The title argument does
    not set the figure title anymore but the axis title.
  * load_surf_mesh loaded FreeSurfer specific surface files (e.g. .pial)
    with a shift in the coordinates. This is fixed by adding the c_ras
    coordinates to the mesh coordinates
  * Function nilearn.glm.second_level.second_level._check_second_level_input
    now raises an error when flm_object argument is False and
    second_level_input is a list of FirstLevelModel
  * Function resample_img now warns the user if the provided image has
    an sform code equal to 0 or None
  * Fix usage of scipy.stats.gamma.pdf in _gamma_difference_hrf function
    under nilearn/glm/first_level/hemodynamic_models.py, which resulted
    in slight distortion of HRF
  * Fix bug introduced due to a fix in the pre-release version of scipy
    (1.9.0rc1) which now enforces that elements of a band-pass filter must
    meet condition Wn[0] < Wn[1]. Now if band-pass elements are equal
    butterworth returns an unfiltered signal with a warning
  * The parameter alpha is now correctly passed to plot_glass_brain in
    plot_connectome
  * Fix plotting of background image in view_img when the background is
    not the MNI template
  * Fix the typographic error on the page Default Mode Network
    extraction of ADHD dataset
  * Add sample_masks to fit for censoring time points
  * Function run_glm and class FirstLevelModel now accept a random_state
    parameter, which allows users to seed the KMeans cluster model used
    to estimate AR coefficients
  * Conform seeding and docstrings in module _utils.data_gen
  * Docstrings of module second_level were improved
  * In get_clusters_table, when the center of mass of a binary
    cluster falls outside the cluster, report the nearest within-cluster
    voxel instead
  * Add n_elements_ attribute to masker classes
  * Functions expecting string filesystem paths now also accept
    path-like objects
  * Contributing guidelines now include a recommendation to run flake8
    locally on the branch diff with main
  * Improvements to permuted_ols and non_parametric_inference with TFCE
    statistic runtime
  * NiftiLabelsMasker now accepts 1-dimensional arrays in its
    inverse_transform method
  * Function plot_carpet argument cmap now respects behaviour specified
    by docs and changes the color of the carpet_plot. Changing the label
    colors is now delegated to a new variable cmap_labels
  * Function fetch_surf_fsaverage no longer supports the previously
    deprecated option fsaverage5_sphere
  * Classes RegressionResults, SimpleRegressionResults, OLSModel,
    and LikelihoodModelResults no longer support deprecated shortened
    attribute names, including df_resid, wdesign, wresid, norm_resid,
    resid, and wY
  * Function fetch_openneuro_dataset_index is now deprecated in favor
    of the new fetch_ds000030_urls function
  * 64-bit integers in Nifti files: some tools such as FSL, SPM and
    AFNI cannot handle Nifti images containing 64-bit integers.
    To avoid compatibility issues, it is best to avoid writing such
    images and in the future trying to create them with nibabel
    without explicitly specifying a data type will result in an error.
    To avoid this, new_img_like now warns when given int64 arrays
    and converts them to int32 when possible (ie when it would not
    result in an overflow). Moreover, any atlas fetcher that returned
    int64 images now produces images containing smaller ints.
  * Refactors fmriprep confound loading such that that the parsing
    of the relevant image file and the loading of the confounds are
    done in separate steps
  * Private submodules, functions, and classes from the decomposition
    module now start with a “_” character to make it clear that they
    are not part of the public API
  * Convert references in nilearn/glm/regression.py and
    nilearn/glm/thresholding.py to use footcite/footbibliography
  * Boolean input data in new_img_like now defaults to np.uint8
    instead of np.int8
  * The current behavior of maskers’ transform on 3D niimg inputs,
    in which a 2D array is returned, is deprecated, and 1D arrays
    will be returned starting in version 0.12
* Fri Sep 16 2022 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Disable multi-thread tests until fixed upstream -- gh#nilearn/nilearn#3359
* Tue Jul 12 2022 Markéta Machová <mmachova@suse.com>
- Update to 0.9.1
  * Python 3.6 is deprecated and will be removed in release 0.10
  * Nibabel 2.x is no longer supported
  * Surface plotting functions can now produce interactive plots
    with Plotly
  * New module nilearn.interfaces to implement loading and saving
    utilities with various interfaces
  * New functions load_confounds and load_confounds_strategy to
    load confound variables easily from fMRIPrep outputs
  * New class HierarchicalKMeans which yields more balanced
    clusters than KMeans. It is also callable through Parcellations
    using method=hierarchical_kmeans
  * Masker objects like NiftiMasker now belong to the new module
    nilearn.maskers. The old import style, through the module
    input_data, still works but has been deprecated
  * Class NiftiMapsMasker can now generate HTML reports in the same
    way as NiftiMasker and NiftiLabelsMasker
  * The contributing documentation and maintenance pages were improved
  * many more changes, see upstream changelog
- Add upstream patch fix-test-decoder.patch
- Delete upstreamed patches:
  * nilearn-pr3136-pythoncall.patch
  * nilearn-pr3094-py310.patch
* Thu Jan 20 2022 Ben Greiner <code@bnavigator.de>
- Update to 0.8.1
  * New atlas fetcher nilearn.datasets.fetch_atlas_juelich to
    download Juelich atlas from FSL.
  * New grey and white-matter template and mask loading functions:
    nilearn.datasets.load_mni152_gm_template,
    nilearn.datasets.load_mni152_wm_template,
    nilearn.datasets.load_mni152_gm_mask, and
    nilearn.datasets.load_mni152_wm_mask
  * Nilearn development process has been reworked. It now provides
    insights on nilearn organization as a project as well as more
    explicit Contribution Guidelines.
  * nilearn.image.binarize_img binarizes images into 0 and 1.
  * nilearn.input_data.NiftiLabelsMasker can now generate HTML
    reports in the same way as nilearn.input_data.NiftiMasker.
  * nilearn.signal.clean accepts new parameter sample_mask. shape:
    (number of scans - number of volumes removed, )
  * All inherent classes of nilearn.input_data.BaseMasker can use
    parameter sample_mask for sub-sample masking.
  * Fetcher nilearn.datasets.fetch_surf_fsaverage now accepts
    fsaverage3, fsaverage4 and fsaverage6 as values for parameter
    mesh, so that all resolutions of fsaverage from 3 to 7 are now
    available.
  * Fetcher nilearn.datasets.fetch_surf_fsaverage now provides
    attributes {area, curv, sphere, thick}_{left, right} for all
    fsaverage resolutions.
  * nilearn.glm.first_level.run_glm now allows auto regressive
    noise models of order greater than one.
  * Support for Nibabel 2.x is deprecated and will be removed in
    the 0.9 release.
- Add nilearn-pr3094-py310.patch -- gh#nilearn/nilearn#3094
- Add nilearn-pr3136-pythoncall.patch -- gh#nilearn/nilearn#3136
- Only test on 64-bit platforms
  - - http://nilearn.github.io/introduction.html#installation
* Fri Apr  9 2021 Markéta Machová <mmachova@suse.com>
- Update to 0.7.1
  * New atlas fetcher nilearn.datasets.fetch_atlas_difumo to download
    Dictionaries of Functional Modes, or “DiFuMo”, that can serve as
    atlases to extract functional signals with different dimensionalities.
  * nilearn.decoding.Decoder and nilearn.decoding.DecoderRegressor is now
    implemented with random predictions to estimate a chance level.
  * Some functions are now implemented with new display mode Mosaic. That
    implies plotting 3D maps in multiple columns and rows in a single axes.
- Drop nilearn-fix-aarch64.patch
* Fri Jan 29 2021 Ben Greiner <code@bnavigator.de>
- Skip python36 build because Tumbleweed updates to SciPy 1.6.0
  which dropped support for Python 3.6 (NEP 29)
* Fri Nov 20 2020 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Add runtime deps: python-requests
* Mon Nov 16 2020 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Update to 0.7.0
- Add patch to fix aarch64 test:
  * nilearn-fix-aarch64.patch
- Drop upstreamed patches:
  * fix-test_save_cmap.patch
  * update-numpy-warning.patch
- Disable 'test_clean_confounds' and 'test_reorder_img_mirror '
  until we have a fix. See:
    https://github.com/nilearn/nilearn/issues/2608
    https://github.com/nilearn/nilearn/issues/2610
* Wed Oct 14 2020 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Backport patches to fix some tests:
  * update-numpy-warning.patch - https://github.com/nilearn/nilearn/pull/2530
  * fix-test_save_cmap.patch   - https://github.com/nilearn/nilearn/pull/2543
* Wed Apr 29 2020 Tomáš Chvátal <tchvatal@suse.com>
- Use xdist to speedup the tests to take less than 30 mins
* Thu Jan 30 2020 Todd R <toddrme2178@gmail.com>
- Update to version 0.6.1
  + ENHANCEMENTS
  * html pages use the user-provided plot title, if any, as their title
  + Fixes
  * Fetchers for developmental_fmri and localizer datasets resolve URLs correctly.
* Mon Jan  6 2020 Todd R <toddrme2178@gmail.com>
- Update to version 0.6.0
  + HIGHLIGHTS
  * Python2 and 3.4 are no longer supported. We recommend upgrading to Python 3.6 minimum.
  * Support for Python3.5 wil be removed in the 0.7.x release.
    Users with a Python3.5 environment will be warned at their first Nilearn import.
  * joblib is now a dependency
  * Minimum supported versions of packages have been bumped up.
    > Matplotlib -- v2.0
    > Scikit-learn -- v0.19
    > Scipy -- v0.19
  + NEW
  * A new method for :class:`nilearn.input_data.NiftiMasker` instances
    for generating reports viewable in a web browser, Jupyter Notebook, or VSCode.
  * A new function :func:`nilearn.image.get_data` to replace the deprecated
    nibabel method `Nifti1Image.get_data`. Now use `nilearn.image.get_data(img)`
    rather than `img.get_data()`. This is because Nibabel is removing the
    `get_data` method. You may also consider using the Nibabel
    `Nifti1Image.get_fdata`, which returns the data cast to floating-point.
    See https://github.com/nipy/nibabel/wiki/BIAP8 .
    As a benefit, the `get_data` function works on niimg-like objects such as
    filenames (see http://nilearn.github.io/manipulating_images/input_output.html ).
  * Parcellation method ReNA: Fast agglomerative clustering based on recursive
    nearest neighbor grouping.
    Yields very fast & accurate models, without creation of giant
    clusters.
  * Plot connectome strength
    Use :func:`nilearn.plotting.plot_connectome_strength` to plot the strength of a
    connectome on a glass brain.  Strength is absolute sum of the edges at a node.
  * Optimization to image resampling
  * New brain development fMRI dataset fetcher
    :func:`nilearn.datasets.fetch_development_fmri` can be used to download
    movie-watching data in children and adults. A light-weight dataset
    implemented for teaching and usage in the examples. All the connectivity examples
    are changed from ADHD to brain development fmri dataset.
  + ENHANCEMENTS
  * :func:`nilearn.plotting.view_img_on_surf`, :func:`nilearn.plotting.view_surf`
    and :func:`nilearn.plotting.view_connectome` can display a title, and allow
    disabling the colorbar, and setting its height and the fontsize of its ticklabels.
  * Rework of the standardize-options of :func:`nilearn.signal.clean` and the various Maskers
    in `nilearn.input_data`. You can now set `standardize` to `zscore` or `psc`. `psc` stands
    for `Percent Signal Change`, which can be a meaningful metric for BOLD.
  * Class :class:`nilearn.input_data.NiftiLabelsMasker` now accepts an optional
    `strategy` parameter which allows it to change the function used to reduce
    values within each labelled ROI. Available functions include mean, median,
    minimum, maximum, standard_deviation and variance.
    This change is also introduced in :func:`nilearn.regions.img_to_signals_labels`.
  * :func:`nilearn.plotting.view_surf` now accepts surface data provided as a file
    path.
  + CHANGES
  * :func:`nilearn.plotting.plot_img` now has explicit keyword arguments `bg_img`,
    `vmin` and `vmax` to control the background image and the bounds of the
    colormap. These arguments were already accepted in `kwargs` but not documented
    before.
  + FIXES
  * :class:`nilearn.input_data.NiftiLabelsMasker` no longer truncates region means to their integral part
    when input images are of integer type.
  * The arg `version='det'` in :func:`nilearn.datasets.fetch_atlas_pauli_2017` now  works as expected.
  * `pip install nilearn` now installs the necessary dependencies.
  * Lots of other fixes in documentation and examples. More detailed change list follows:
- Drop python2 support
* Fri Jul 26 2019 Todd R <toddrme2178@gmail.com>
- Initial version
